# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: plugin.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from robomotion import struct_pb2 as struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x0cplugin.proto\x12\x05proto\x1a\x0cstruct.proto"2\n\x05\x45rror\x12\n\n\x02OK\x18\x02 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t"1\n\x0bInitRequest\x12\x14\n\x0c\x65vent_server\x18\x01 \x01(\r\x12\x0c\n\x04port\x18\x02 \x01(\r"/\n\x0fOnCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x0c"/\n\x10OnCreateResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error"3\n\x10OnMessageRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x11\n\tinMessage\x18\x02 \x01(\x0c"D\n\x11OnMessageResponse\x12\x12\n\noutMessage\x18\x01 \x01(\x0c\x12\x1b\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x0c.proto.Error"\x1e\n\x0eOnCloseRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t".\n\x0fOnCloseResponse\x12\x1b\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x0c.proto.Error"\x07\n\x05\x45mpty";\n\x0c\x44\x65\x62ugRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\x0c"2\n\x14\x45mitFlowEventRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"/\n\x10\x45mitInputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\r\n\x05input\x18\x02 \x01(\x0c"?\n\x11\x45mitOutputRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0e\n\x06output\x18\x02 \x01(\x0c\x12\x0c\n\x04port\x18\x03 \x01(\x05"?\n\x10\x45mitErrorRequest\x12\x0c\n\x04guid\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07message\x18\x03 \x01(\t"6\n\x13GetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t"=\n\x14GetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"D\n\x13SetVaultItemRequest\x12\x0f\n\x07vaultId\x18\x01 \x01(\t\x12\x0e\n\x06ItemId\x18\x02 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c"=\n\x14SetVaultItemResponse\x12%\n\x04item\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"\'\n\x08Variable\x12\r\n\x05scope\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t"7\n\x12GetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable"=\n\x13GetVariableResponse\x12&\n\x05value\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"_\n\x12SetVariableRequest\x12!\n\x08variable\x18\x01 \x01(\x0b\x32\x0f.proto.Variable\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct">\n\x14GetRobotInfoResponse\x12&\n\x05robot\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct"5\n\x11\x41ppRequestRequest\x12\x0f\n\x07request\x18\x01 \x01(\x0c\x12\x0f\n\x07timeout\x18\x02 \x01(\x05"&\n\x12\x41ppRequestResponse\x12\x10\n\x08response\x18\x01 \x01(\x0c"0\n\x13\x44ownloadFileRequest\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t2\xe7\x01\n\x04Node\x12(\n\x04Init\x12\x12.proto.InitRequest\x1a\x0c.proto.Empty\x12;\n\x08OnCreate\x12\x16.proto.OnCreateRequest\x1a\x17.proto.OnCreateResponse\x12>\n\tOnMessage\x12\x17.proto.OnMessageRequest\x1a\x18.proto.OnMessageResponse\x12\x38\n\x07OnClose\x12\x15.proto.OnCloseRequest\x1a\x16.proto.OnCloseResponse2\x82\x06\n\rRuntimeHelper\x12#\n\x05\x43lose\x12\x0c.proto.Empty\x1a\x0c.proto.Empty\x12*\n\x05\x44\x65\x62ug\x12\x13.proto.DebugRequest\x1a\x0c.proto.Empty\x12:\n\rEmitFlowEvent\x12\x1b.proto.EmitFlowEventRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitInput\x12\x17.proto.EmitInputRequest\x1a\x0c.proto.Empty\x12\x34\n\nEmitOutput\x12\x18.proto.EmitOutputRequest\x1a\x0c.proto.Empty\x12\x32\n\tEmitError\x12\x17.proto.EmitErrorRequest\x1a\x0c.proto.Empty\x12G\n\x0cGetVaultItem\x12\x1a.proto.GetVaultItemRequest\x1a\x1b.proto.GetVaultItemResponse\x12G\n\x0cSetVaultItem\x12\x1a.proto.SetVaultItemRequest\x1a\x1b.proto.SetVaultItemResponse\x12\x44\n\x0bGetVariable\x12\x19.proto.GetVariableRequest\x1a\x1a.proto.GetVariableResponse\x12\x36\n\x0bSetVariable\x12\x19.proto.SetVariableRequest\x1a\x0c.proto.Empty\x12\x39\n\x0cGetRobotInfo\x12\x0c.proto.Empty\x1a\x1b.proto.GetRobotInfoResponse\x12\x41\n\nAppRequest\x12\x18.proto.AppRequestRequest\x1a\x19.proto.AppRequestResponse\x12\x38\n\x0c\x44ownloadFile\x12\x1a.proto.DownloadFileRequest\x1a\x0c.proto.Emptyb\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "plugin_pb2", globals())
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _ERROR._serialized_start = 37
    _ERROR._serialized_end = 87
    _INITREQUEST._serialized_start = 89
    _INITREQUEST._serialized_end = 138
    _ONCREATEREQUEST._serialized_start = 140
    _ONCREATEREQUEST._serialized_end = 187
    _ONCREATERESPONSE._serialized_start = 189
    _ONCREATERESPONSE._serialized_end = 236
    _ONMESSAGEREQUEST._serialized_start = 238
    _ONMESSAGEREQUEST._serialized_end = 289
    _ONMESSAGERESPONSE._serialized_start = 291
    _ONMESSAGERESPONSE._serialized_end = 359
    _ONCLOSEREQUEST._serialized_start = 361
    _ONCLOSEREQUEST._serialized_end = 391
    _ONCLOSERESPONSE._serialized_start = 393
    _ONCLOSERESPONSE._serialized_end = 439
    _EMPTY._serialized_start = 441
    _EMPTY._serialized_end = 448
    _DEBUGREQUEST._serialized_start = 450
    _DEBUGREQUEST._serialized_end = 509
    _EMITFLOWEVENTREQUEST._serialized_start = 511
    _EMITFLOWEVENTREQUEST._serialized_end = 561
    _EMITINPUTREQUEST._serialized_start = 563
    _EMITINPUTREQUEST._serialized_end = 610
    _EMITOUTPUTREQUEST._serialized_start = 612
    _EMITOUTPUTREQUEST._serialized_end = 675
    _EMITERRORREQUEST._serialized_start = 677
    _EMITERRORREQUEST._serialized_end = 740
    _GETVAULTITEMREQUEST._serialized_start = 742
    _GETVAULTITEMREQUEST._serialized_end = 796
    _GETVAULTITEMRESPONSE._serialized_start = 798
    _GETVAULTITEMRESPONSE._serialized_end = 859
    _SETVAULTITEMREQUEST._serialized_start = 861
    _SETVAULTITEMREQUEST._serialized_end = 929
    _SETVAULTITEMRESPONSE._serialized_start = 931
    _SETVAULTITEMRESPONSE._serialized_end = 992
    _VARIABLE._serialized_start = 994
    _VARIABLE._serialized_end = 1033
    _GETVARIABLEREQUEST._serialized_start = 1035
    _GETVARIABLEREQUEST._serialized_end = 1090
    _GETVARIABLERESPONSE._serialized_start = 1092
    _GETVARIABLERESPONSE._serialized_end = 1153
    _SETVARIABLEREQUEST._serialized_start = 1155
    _SETVARIABLEREQUEST._serialized_end = 1250
    _GETROBOTINFORESPONSE._serialized_start = 1252
    _GETROBOTINFORESPONSE._serialized_end = 1314
    _APPREQUESTREQUEST._serialized_start = 1316
    _APPREQUESTREQUEST._serialized_end = 1369
    _APPREQUESTRESPONSE._serialized_start = 1371
    _APPREQUESTRESPONSE._serialized_end = 1409
    _DOWNLOADFILEREQUEST._serialized_start = 1411
    _DOWNLOADFILEREQUEST._serialized_end = 1459
    _NODE._serialized_start = 1462
    _NODE._serialized_end = 1693
    _RUNTIMEHELPER._serialized_start = 1696
    _RUNTIMEHELPER._serialized_end = 2466
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from robomotion import plugin_pb2 as plugin__pb2


class NodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Init = channel.unary_unary(
            "/proto.Node/Init",
            request_serializer=plugin__pb2.InitRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.OnCreate = channel.unary_unary(
            "/proto.Node/OnCreate",
            request_serializer=plugin__pb2.OnCreateRequest.SerializeToString,
            response_deserializer=plugin__pb2.OnCreateResponse.FromString,
        )
        self.OnMessage = channel.unary_unary(
            "/proto.Node/OnMessage",
            request_serializer=plugin__pb2.OnMessageRequest.SerializeToString,
            response_deserializer=plugin__pb2.OnMessageResponse.FromString,
        )
        self.OnClose = channel.unary_unary(
            "/proto.Node/OnClose",
            request_serializer=plugin__pb2.OnCloseRequest.SerializeToString,
            response_deserializer=plugin__pb2.OnCloseResponse.FromString,
        )


class NodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Init(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OnCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OnMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def OnClose(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_NodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Init": grpc.unary_unary_rpc_method_handler(
            servicer.Init,
            request_deserializer=plugin__pb2.InitRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        "OnCreate": grpc.unary_unary_rpc_method_handler(
            servicer.OnCreate,
            request_deserializer=plugin__pb2.OnCreateRequest.FromString,
            response_serializer=plugin__pb2.OnCreateResponse.SerializeToString,
        ),
        "OnMessage": grpc.unary_unary_rpc_method_handler(
            servicer.OnMessage,
            request_deserializer=plugin__pb2.OnMessageRequest.FromString,
            response_serializer=plugin__pb2.OnMessageResponse.SerializeToString,
        ),
        "OnClose": grpc.unary_unary_rpc_method_handler(
            servicer.OnClose,
            request_deserializer=plugin__pb2.OnCloseRequest.FromString,
            response_serializer=plugin__pb2.OnCloseResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "proto.Node", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class Node(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Init(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Node/Init",
            plugin__pb2.InitRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def OnCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Node/OnCreate",
            plugin__pb2.OnCreateRequest.SerializeToString,
            plugin__pb2.OnCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def OnMessage(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Node/OnMessage",
            plugin__pb2.OnMessageRequest.SerializeToString,
            plugin__pb2.OnMessageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def OnClose(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.Node/OnClose",
            plugin__pb2.OnCloseRequest.SerializeToString,
            plugin__pb2.OnCloseResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )


class RuntimeHelperStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Close = channel.unary_unary(
            "/proto.RuntimeHelper/Close",
            request_serializer=plugin__pb2.Empty.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.Debug = channel.unary_unary(
            "/proto.RuntimeHelper/Debug",
            request_serializer=plugin__pb2.DebugRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitFlowEvent = channel.unary_unary(
            "/proto.RuntimeHelper/EmitFlowEvent",
            request_serializer=plugin__pb2.EmitFlowEventRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitInput = channel.unary_unary(
            "/proto.RuntimeHelper/EmitInput",
            request_serializer=plugin__pb2.EmitInputRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitOutput = channel.unary_unary(
            "/proto.RuntimeHelper/EmitOutput",
            request_serializer=plugin__pb2.EmitOutputRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.EmitError = channel.unary_unary(
            "/proto.RuntimeHelper/EmitError",
            request_serializer=plugin__pb2.EmitErrorRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.GetVaultItem = channel.unary_unary(
            "/proto.RuntimeHelper/GetVaultItem",
            request_serializer=plugin__pb2.GetVaultItemRequest.SerializeToString,
            response_deserializer=plugin__pb2.GetVaultItemResponse.FromString,
        )
        self.SetVaultItem = channel.unary_unary(
            "/proto.RuntimeHelper/SetVaultItem",
            request_serializer=plugin__pb2.SetVaultItemRequest.SerializeToString,
            response_deserializer=plugin__pb2.SetVaultItemResponse.FromString,
        )
        self.GetVariable = channel.unary_unary(
            "/proto.RuntimeHelper/GetVariable",
            request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
            response_deserializer=plugin__pb2.GetVariableResponse.FromString,
        )
        self.SetVariable = channel.unary_unary(
            "/proto.RuntimeHelper/SetVariable",
            request_serializer=plugin__pb2.SetVariableRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )
        self.GetRobotInfo = channel.unary_unary(
            "/proto.RuntimeHelper/GetRobotInfo",
            request_serializer=plugin__pb2.Empty.SerializeToString,
            response_deserializer=plugin__pb2.GetRobotInfoResponse.FromString,
        )
        self.AppRequest = channel.unary_unary(
            "/proto.RuntimeHelper/AppRequest",
            request_serializer=plugin__pb2.AppRequestRequest.SerializeToString,
            response_deserializer=plugin__pb2.AppRequestResponse.FromString,
        )
        self.DownloadFile = channel.unary_unary(
            "/proto.RuntimeHelper/DownloadFile",
            request_serializer=plugin__pb2.DownloadFileRequest.SerializeToString,
            response_deserializer=plugin__pb2.Empty.FromString,
        )


class RuntimeHelperServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Close(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def Debug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def EmitFlowEvent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def EmitInput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def EmitOutput(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def EmitError(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetVaultItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SetVaultItem(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetVariable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def SetVariable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetRobotInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def AppRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DownloadFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_RuntimeHelperServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "Close": grpc.unary_unary_rpc_method_handler(
            servicer.Close,
            request_deserializer=plugin__pb2.Empty.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        "Debug": grpc.unary_unary_rpc_method_handler(
            servicer.Debug,
            request_deserializer=plugin__pb2.DebugRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        "EmitFlowEvent": grpc.unary_unary_rpc_method_handler(
            servicer.EmitFlowEvent,
            request_deserializer=plugin__pb2.EmitFlowEventRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        "EmitInput": grpc.unary_unary_rpc_method_handler(
            servicer.EmitInput,
            request_deserializer=plugin__pb2.EmitInputRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        "EmitOutput": grpc.unary_unary_rpc_method_handler(
            servicer.EmitOutput,
            request_deserializer=plugin__pb2.EmitOutputRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        "EmitError": grpc.unary_unary_rpc_method_handler(
            servicer.EmitError,
            request_deserializer=plugin__pb2.EmitErrorRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        "GetVaultItem": grpc.unary_unary_rpc_method_handler(
            servicer.GetVaultItem,
            request_deserializer=plugin__pb2.GetVaultItemRequest.FromString,
            response_serializer=plugin__pb2.GetVaultItemResponse.SerializeToString,
        ),
        "SetVaultItem": grpc.unary_unary_rpc_method_handler(
            servicer.SetVaultItem,
            request_deserializer=plugin__pb2.SetVaultItemRequest.FromString,
            response_serializer=plugin__pb2.SetVaultItemResponse.SerializeToString,
        ),
        "GetVariable": grpc.unary_unary_rpc_method_handler(
            servicer.GetVariable,
            request_deserializer=plugin__pb2.GetVariableRequest.FromString,
            response_serializer=plugin__pb2.GetVariableResponse.SerializeToString,
        ),
        "SetVariable": grpc.unary_unary_rpc_method_handler(
            servicer.SetVariable,
            request_deserializer=plugin__pb2.SetVariableRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
        "GetRobotInfo": grpc.unary_unary_rpc_method_handler(
            servicer.GetRobotInfo,
            request_deserializer=plugin__pb2.Empty.FromString,
            response_serializer=plugin__pb2.GetRobotInfoResponse.SerializeToString,
        ),
        "AppRequest": grpc.unary_unary_rpc_method_handler(
            servicer.AppRequest,
            request_deserializer=plugin__pb2.AppRequestRequest.FromString,
            response_serializer=plugin__pb2.AppRequestResponse.SerializeToString,
        ),
        "DownloadFile": grpc.unary_unary_rpc_method_handler(
            servicer.DownloadFile,
            request_deserializer=plugin__pb2.DownloadFileRequest.FromString,
            response_serializer=plugin__pb2.Empty.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "proto.RuntimeHelper", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class RuntimeHelper(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Close(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/Close",
            plugin__pb2.Empty.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def Debug(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/Debug",
            plugin__pb2.DebugRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def EmitFlowEvent(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/EmitFlowEvent",
            plugin__pb2.EmitFlowEventRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def EmitInput(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/EmitInput",
            plugin__pb2.EmitInputRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def EmitOutput(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/EmitOutput",
            plugin__pb2.EmitOutputRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def EmitError(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/EmitError",
            plugin__pb2.EmitErrorRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetVaultItem(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/GetVaultItem",
            plugin__pb2.GetVaultItemRequest.SerializeToString,
            plugin__pb2.GetVaultItemResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SetVaultItem(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/SetVaultItem",
            plugin__pb2.SetVaultItemRequest.SerializeToString,
            plugin__pb2.SetVaultItemResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetVariable(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/GetVariable",
            plugin__pb2.GetVariableRequest.SerializeToString,
            plugin__pb2.GetVariableResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def SetVariable(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/SetVariable",
            plugin__pb2.SetVariableRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetRobotInfo(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/GetRobotInfo",
            plugin__pb2.Empty.SerializeToString,
            plugin__pb2.GetRobotInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def AppRequest(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/AppRequest",
            plugin__pb2.AppRequestRequest.SerializeToString,
            plugin__pb2.AppRequestResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DownloadFile(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/proto.RuntimeHelper/DownloadFile",
            plugin__pb2.DownloadFileRequest.SerializeToString,
            plugin__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from pathlib import Path
from sys import platform
from packaging import version


class File:
    @staticmethod
    def temp_dir():
        home = str(Path.home())
        is_win = platform.startswith("win")
        if is_win:
            return "%s\\AppData\\Local\\Temp\\Robomotion" % home
        return "/tmp/robomotion"


class Version:
    @staticmethod
    def is_version_less_than(ver: str, other: str) -> bool:
        v = version.parse(ver)
        v2 = version.parse(other)
        return v < v2



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: struct.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cstruct.proto\x12\x0fgoogle.protobuf\"\x84\x01\n\x06Struct\x12\x33\n\x06\x66ields\x18\x01 \x03(\x0b\x32#.google.protobuf.Struct.FieldsEntry\x1a\x45\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.google.protobuf.Value:\x02\x38\x01\"\xea\x01\n\x05Value\x12\x30\n\nnull_value\x18\x01 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12\x16\n\x0cnumber_value\x18\x02 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x12/\n\x0cstruct_value\x18\x05 \x01(\x0b\x32\x17.google.protobuf.StructH\x00\x12\x30\n\nlist_value\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValueH\x00\x42\x06\n\x04kind\"3\n\tListValue\x12&\n\x06values\x18\x01 \x03(\x0b\x32\x16.google.protobuf.Value*\x1b\n\tNullValue\x12\x0e\n\nNULL_VALUE\x10\x00\x42\x81\x01\n\x13\x63om.google.protobufB\x0bStructProtoP\x01Z1github.com/golang/protobuf/ptypes/struct;structpb\xf8\x01\x01\xa2\x02\x03GPB\xaa\x02\x1eGoogle.Protobuf.WellKnownTypesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'struct_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023com.google.protobufB\013StructProtoP\001Z1github.com/golang/protobuf/ptypes/struct;structpb\370\001\001\242\002\003GPB\252\002\036Google.Protobuf.WellKnownTypes'
  _STRUCT_FIELDSENTRY._options = None
  _STRUCT_FIELDSENTRY._serialized_options = b'8\001'
  _NULLVALUE._serialized_start=458
  _NULLVALUE._serialized_end=485
  _STRUCT._serialized_start=34
  _STRUCT._serialized_end=166
  _STRUCT_FIELDSENTRY._serialized_start=97
  _STRUCT_FIELDSENTRY._serialized_end=166
  _VALUE._serialized_start=169
  _VALUE._serialized_end=403
  _LISTVALUE._serialized_start=405
  _LISTVALUE._serialized_end=456
# @@protoc_insertion_point(module_scope)
